cstr_to_string

Function cstr_to_string 

pub unsafe fn cstr_to_string(ptr: *const c_char) -> Option<String>
Used by the host to recover a string returned from a plugin.

Safety

ptr must have been returned by the corresponding plugin’s introspect function and freed using its free_string entry.